@@ -56,6 +56,8 @@ plot(V, main="Pixel image on a linear network")
 
 fanfare("II. Graphics")
 
+par(mar=c(5,4,2,3)+0.1)
+
 plot(letterR, col="green", border="red", lwd=2, main="Polygonal window with colour fill")
 plot(letterR, hatch=TRUE, spacing=0.15, angle=30, main="Polygonal window with line shading")
 plot(letterR, hatch=TRUE, hatchargs=list(texture=8, spacing=0.12),
@@ -119,6 +121,19 @@ plot(V, main="Pixel image on a linear network (colour plot)")
 plot(V, style="w", main="Pixel image on a linear network (width plot)")
 persp(V, phi=25, theta=-35, expand=0.2, main="Pixel image on a linear network (perspective plot)")
 
+XL <- rpoislpp(20, simplenet)
+plot(XL, main="Point pattern on a network (default plot)")
+plot(XL,
+     shape="crossticks", size=0.04,
+     main="Point pattern on a network (crossticks plot)")
+
+plot(chicago, cols=1:7,
+     main="Multitype point pattern on a network (symbols and colours)")
+plot(dendrite, shape="crossticks", cols=2:4, size=8,
+     leg.side="bottom", leg.args=list(lwd=3),
+     main="Multitype point pattern on a network (crossticks and colours)")
+
+
 fanfare("III. Conversion between types")
 
 W <- as.owin(chorley)
@@ -159,12 +174,13 @@ plot(split(lansing),
 
 plot(longleaf, main="Longleaf Pines data")
 plot(cut(longleaf, breaks=3),
-     main=c("cut operation", "cut(longleaf, breaks=3)"))
+     main=c("cut operation", "cut(longleaf, breaks=3)"),
+     cols=2:4)
 
-Z <- dirichlet(runifpoint(16))
+Z <- dirichlet(runifpoint(10))
 X <- runifpoint(100)
 
-plot(cut(X,Z), main="points cut by tessellation", leg.side="left")
+plot(cut(X,Z), main="points cut by tessellation", leg.side="left", cols=1:10)
 plot(Z, add=TRUE)
 
 plot(split(X, Z),
@@ -223,7 +239,7 @@ rh <- rhohat(X,D)
 plot(rh,
      main="Smoothed rate estimate",
      xlab="Distance to nearest fault (km)",
-     legend=FALSE)
+     legend=FALSE, xlim=c(0, 20))
 plot(predict(rh), main="predict(rhohat(X,D))")
 
 Z <- density(cells, 0.07)
@@ -410,6 +426,7 @@ plot(spruces, cex.main=0.8, markscale=10)
 par(pty="s", mar=0.2+c(2,3,2,0))
 plot(markvario(spruces), main="Mark variogram", legendpos="topright")
 par(parsave)
+par(mar=0.2+c(4,4,3,2))
 
 plot(listof("Emark(spruces)"=Emark(spruces),
             "Vmark(spruces)"=Vmark(spruces)),
@@ -442,7 +459,7 @@ par(mfrow=c(1,1))
 
 fanfare("VII. Model-fitting")
 
-parsave <- par(mar=0.2+c(1,1,3,2))
+parsave <- par(mar=0.2+c(1,1,3,3))
 plot(japanesepines)
 fit <- ppm(japanesepines ~1)
 print(fit)
@@ -746,11 +763,12 @@ showoffK <- function(Y, current, ..., fullpicture,rad) {
 	plot(fullpicture,
              main=c("Animation using `applynbd'", "explaining the K function"))
 	points(Y, cex=2)
-        u <- current
-	points(u[1],u[2],pch="+",cex=3)
+        ux <- current[["x"]]
+        uy <- current[["y"]]
+	points(ux,uy,pch="+",cex=3)
 	theta <- seq(0,2*pi,length=100)
-	polygon(u[1]+ rad * cos(theta),u[2]+rad*sin(theta))
-	text(u[1]+rad/3,u[2]+rad/2,Y$n,cex=3)
+	polygon(ux + rad * cos(theta), uy + rad*sin(theta))
+	text(ux+rad/3,uy+rad/2,Y$n,cex=3)
         if(runif(1) < 0.2) Sys.sleep(runif(1, max=0.4))
 	return(npoints(Y))
 }
